<!DOCTYPE html>
<html>
<head>
  <meta charset="UTF-8"/>
  <style>
    body {
      background: #eee;
    }
    #app {
      display: flex;
      justify-content: center;
      align-items: center;
      text-align: center;
    }
  </style>
  <script defer src="{{ url_for('static', filename='bundle.js') }}"></script>
</head>
<body>
<div id="app"></div>
</body>
</html>
