import dataclasses


@dataclasses.dataclass(frozen=True)
class __CONST:
    AtCoderContestsURL = "https://atcoder.jp/contests/"
    AtCoderPastMarathonContestsURL = "https://atcoder.jp/contests/archive?ratedType=0&category=1200"


CONST = __CONST()




